pub enum SurfacePath {
    Circle(Circle<2>),
    Line(Line<2>),
}
A path through surface (2D) space

Variants



Circle(Circle<2>)

A circle



Line(Line<2>)

A line

Implementations

source

impl SurfacePath

source

pub fn circle_from_center_and_radius( center: impl Into<Point<2>>, radius: impl Into<Scalar> ) -> Self

Build a circle from the given radius

source

pub fn u_axis() -> Self

Build a line that represents the u-axis of the surface its on

source

pub fn v_axis() -> Self

Build a line that represents the v-axis of the surface its on

source

pub fn line_from_points( points: [impl Into<Point<2>>; 2] ) -> (Self, [Point<1>; 2])

Construct a line from two points

Also returns the coordinates of the points on the path.

source

pub fn line_from_points_with_coords( points: [(impl Into<Point<1>>, impl Into<Point<2>>); 2] ) -> Self

Create a line from two points that include line coordinates

source

pub fn point_from_path_coords(&self, point: impl Into<Point<1>>) -> Point<2>

Convert a point on the path into surface coordinates

source

pub fn reverse(self) -> Self

Create a new path that is the reverse of this one