pub struct ObjectSet<T> { /* private fields */ }Expand description
An ordered set of objects
This is the data structure used by all objects that reference multiple objects of the same type. It is a set, not containing any duplicate elements, and it maintains the insertion order of those elements.
Implementations
sourceimpl<T> ObjectSet<T>
impl<T> ObjectSet<T>
sourcepub fn new(handles: impl IntoIterator<Item = Handle<T>>) -> Self
pub fn new(handles: impl IntoIterator<Item = Handle<T>>) -> Self
Create an instances of ObjectSet from an iterator over Handle<T>
Panics
Panics, if the iterator contains duplicate Handles.
sourcepub fn contains(&self, object: &Handle<T>) -> bool
pub fn contains(&self, object: &Handle<T>) -> bool
Indicate whether the set contains the provided object
sourcepub fn nth_circular(&self, index: usize) -> &Handle<T>
pub fn nth_circular(&self, index: usize) -> &Handle<T>
Return the n-th item, treating the index space as circular
If the length of ObjectSet is i, then retrieving the i-th edge using
this method, is the same as retrieving the 0-th one, and so on.
Panics
Panics, if ObjectSet is empty.
sourcepub fn index_of(&self, handle: &Handle<T>) -> Option<usize>
pub fn index_of(&self, handle: &Handle<T>) -> Option<usize>
Return the index of the item, if available
sourcepub fn after(&self, handle: &Handle<T>) -> Option<&Handle<T>>
pub fn after(&self, handle: &Handle<T>) -> Option<&Handle<T>>
Access the item after the provided one
Returns None, if the provided item is not in this iterator.
sourcepub fn pairs(&self) -> impl Iterator<Item = (&Handle<T>, &Handle<T>)>
pub fn pairs(&self) -> impl Iterator<Item = (&Handle<T>, &Handle<T>)>
Access an iterator over the neighboring pairs of all contained objects