Struct fj_core::operations::build::Polygon
source · pub struct Polygon<const D: usize, I: IsInserted = IsInsertedNo> {
pub face: I::T<Face>,
pub half_edges: [Handle<HalfEdge>; D],
pub vertices: [Handle<Vertex>; D],
}Expand description
A polygon
Implementation Note
Currently code that deals with Polygon might assume that the polygon has
no holes. Unless you create a Polygon yourself, or modify a Polygon’s
face field to have interior cycles, this should not affect you.
Fields
face: I::T<Face>The face that forms the polygon
half_edges: [Handle<HalfEdge>; D]The half-edges of the polygon
vertices: [Handle<Vertex>; D]The vertices of the polygon
Implementations
sourceimpl<const D: usize, I: IsInserted> Polygon<D, I>
impl<const D: usize, I: IsInserted> Polygon<D, I>
sourcepub fn replace_face(&self, face: I::T<Face>) -> Self
pub fn replace_face(&self, face: I::T<Face>) -> Self
Replace the face of the polygon
Returns a new instance of Polygon with the replaced face. Also updates
the other fields of Polygon to match the new face.