Struct fj_core::operations::Polygon

source ·
pub struct Polygon<const D: usize, I: IsInserted = IsInsertedNo> {
    pub face: I::T<Face>,
    pub edges: [Handle<HalfEdge>; D],
    pub vertices: [Handle<Vertex>; D],
}
A polygon

Implementation Note

Currently code that deals with Polygon might assume that the polygon has no holes. Unless you create a Polygon yourself, or modify a Polygon’s face field to have interior cycles, this should not affect you.

Fields

face: I::T<Face>

The face that forms the polygon

edges: [Handle<HalfEdge>; D]

The edges of the polygon

vertices: [Handle<Vertex>; D]

The vertices of the polygon