pub struct TetrahedronShell<I: IsInserted = IsInsertedNo> {
    pub shell: I::T<Shell>,
    pub abc: Polygon<3, IsInsertedYes>,
    pub bad: Polygon<3, IsInsertedYes>,
    pub dac: Polygon<3, IsInsertedYes>,
    pub cbd: Polygon<3, IsInsertedYes>,
}
A tetrahedron

A tetrahedron is constructed from 4 points and has 4 faces. For the purpose of naming the fields of this struct, the points are named a, b, c, and d, in the order in which they are passed.

Returned by BuildShell::tetrahedron.

Fields

shell: I::T<Shell>

The shell that forms the tetrahedron

abc: Polygon<3, IsInsertedYes>

The face formed by the points a, b, and c.

bad: Polygon<3, IsInsertedYes>

The face formed by the points b, a, and d.

dac: Polygon<3, IsInsertedYes>

The face formed by the points d, a, and c.

cbd: Polygon<3, IsInsertedYes>

The face formed by the points c, b, and d.