Module fj_core::algorithms
source · Expand description
Collection of algorithms that operate on geometry
Algorithmic code is collected in this module, to keep other modules focused on their respective purpose.
Implementation Note
This module exists in a bit of an in-between state, as some of the things
that are still here are probably better places in the operations module.
Modules
- Approximation of objects
- Compute a bounding volume for an object
- Intersection algorithms
- Sweeping objects along a path to create new objects
- API for transforming objects
- Shape triangulation