Trait fj_core::operations::insert::Insert
source · pub trait Insert: Sized {
type Inserted;
// Required method
fn insert(self, services: &mut Services) -> Self::Inserted;
}Expand description
Insert an object into its respective store
This is the only primitive operation that is directly understood by
Service<Objects>. All other operations are built on top of it.
Required Associated Types
Required Methods
sourcefn insert(self, services: &mut Services) -> Self::Inserted
fn insert(self, services: &mut Services) -> Self::Inserted
Insert the object into its respective store
Inserted objects will automatically be validated in the background. You should not insert an invalid object into the stores, unless you have a specific reason to do so, and you are handling validation errors in a non-standard way.
Object Safety
This trait is not object safe.