Trait fj_core::operations::insert::IsInserted
source · pub trait IsInserted {
type T<T>: Borrow<T>;
}Expand description
Indicate whether an object has been inserted
Intended to be used as a type parameter bound for structs that need to track whether their contents have been inserted or not.
Required Associated Types
Object Safety
This trait is not object safe.