Trait fj_core::operations::Insert
source · pub trait Insert: Sized {
type Inserted;
// Required method
fn insert(self, services: &mut Services) -> Self::Inserted;
}Expand description
Insert an object into its respective store
This is the only primitive operation that is directly understood by
Service<Objects>. All other operations are built on top of it.