Trait fj_core::operations::IsInserted
source · pub trait IsInserted {
type T<T>;
}Expand description
Indicate whether an object has been inserted
Intended to be used as a type parameter bound for structs that need to track whether their contents have been inserted or not.